﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace DataPointsDemo.DomainClasses
{
    public enum TwitterExperience
    {
        Newbie, BeenAround, Ninja
    }

    public enum TweetRating
    {
        Suxorz = 0,
        WorksForMe = 1,
        WatchOutAPlusK = 2
    }
    public enum MaxLength : long { Max = 2147483648L, Min = 255L };

    public class Tweeter
    {
        public Tweeter()
        {
            Tweets = new List<Tweet>();
        }
        public int Id { get; set; }
        [Required]
        public string Name { get; set; }
        [Column("ExperienceCode")]
        public TwitterExperience Experience { get; set; }
        [MaxLength(30), MinLength(5)]
        public string UserName { get; set; }
        [RegularExpression(@"(\w[-._\w]*\w@\w[-._\w]*\w\.\w{2,3})")]
        public string Email { get; set; }
        public string Bio { get; set; }
        public DateTime CreateDate { get; set; }
        public byte[] Avatar { get; set; }
        public ICollection<Tweet> Tweets { get; set; }
        [Timestamp]
        public byte[] RowVersion { get; set; }
        public MaxLength MaxLength { get; set; } //just to see effect of specifying the enum as long
        public string AliasPlusName
        { get { return Name + "(" + UserName + ")"; } }
    }

    public class Tweet
    {
        public int Id { get; set; }
        public DateTime CreateDate { get; set; }
        public string Content { get; set; }
        [Column("RatingCode")]
        public TweetRating Rating { get; set; }
        public Tweeter Alias { get; set; }
        public int AliasId { get; set; }
    }

}


